# Generic Buyer

A generic agent for buying data.

## Description

This agent uses its primary skill, the `fetchai/generic_buyer` skill, to find an agent selling data on the `SOEF` service. 

Once found, it requests specific data, negotiates the price using the `fetchai/fipa` protocol, and if an agreement is reached, pays the proposed amount and receives the data.

## Links

* <a href="https://docs.fetch.ai/aea/generic-skills/" target="_blank">Generic Skills</a>
* <a href="https://docs.fetch.ai/aea/generic-skills-step-by-step/" target="_blank">Generic Skill Step by Step Guide</a>
